@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2010 Miha Čančula <miha.cancula@gmail.com>
+    SPDX-FileCopyrightText: 2018-2022 by Alexander Semke (alexander.semke@web.de)
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,8 +13,6 @@
 #include <expression.h>
 #include <QStringList>
 
-class QTemporaryFile;
-
 class OctaveExpression : public Cantor::Expression
 {
     Q_OBJECT
@@ -22,7 +21,6 @@ public:
     explicit OctaveExpression(Cantor::Session*, bool internal = false);
     ~OctaveExpression();
 
-    void interrupt() override;
     void evaluate() override;
     QString internalCommand() override;
 
@@ -30,7 +28,6 @@ public:
     void parseError(const QString&) override;
     void imageChanged();
 
-public:
     const static QStringList plotExtensions;
 
 private:
