@@ -77,13 +77,13 @@ void OctaveVariableModel::parseNewVariables(Expression::Status status)
             }
 
             QString text = static_cast<Cantor::TextResult*>(m_expr->result())->plain();
-            const QStringList& variableData = text.split(delimiter, QString::SkipEmptyParts);
+            const QStringList& variableData = text.split(delimiter, Qt::SkipEmptyParts);
             QList<Variable> vars;
 
             for (const auto& data : variableData)
             {
                 // every variable data has 4 parts/elements separated by a new line - the name of the variable, its size, type and the actual value
-                const auto& elements = data.split(QLatin1String("\n"), QString::SkipEmptyParts);
+                const auto& elements = data.split(QLatin1String("\n"), Qt::SkipEmptyParts);
                 int count = elements.count();
                 if (count < 6)
                     continue;
@@ -112,7 +112,7 @@ void OctaveVariableModel::parseNewVariables(Expression::Status status)
                 }
 
                 value = value.replace(QStringLiteral("   "), QStringLiteral(" ")); // for vectors Octave is separating the values with three blanks, replace with one
-                vars << Variable(name, value, size.toULongLong(), type, rows + QStringLiteral("x") + columns);
+                vars << Variable(name, std::move(value), size.toULongLong(), type, rows + QStringLiteral("x") + columns);
             }
 
             setVariables(vars);
