@@ -84,7 +84,7 @@ WorksheetEntry::WorksheetEntry(Worksheet* worksheet) : QGraphicsObject(), m_cont
 
 WorksheetEntry::~WorksheetEntry()
 {
-    emit aboutToBeDeleted();
+    Q_EMIT aboutToBeDeleted();
     if (next())
         next()->setPrevious(previous());
     if (previous())
@@ -419,22 +419,23 @@ void WorksheetEntry::populateMenu(QMenu* menu, QPointF pos)
 
     if (m_prev) {
         action = new QAction(QIcon::fromTheme(QLatin1String("go-up")), i18n("Move Up"));
-        connect(action, &QAction::triggered, [=]() {moveToPrevious();});
-        action->setShortcut(Qt::CTRL + Qt::Key_Up);
+    //     connect(action, &QAction::triggered, this, &WorksheetEntry::moveToPrevious); //TODO: doesn't work
+        connect(action, SIGNAL(triggered()), this, SLOT(moveToPrevious()));
+        action->setShortcut(Qt::CTRL | Qt::Key_Up);
         menu->insertAction(firstAction, action);
     }
 
     if (m_next) {
         action = new QAction(QIcon::fromTheme(QLatin1String("go-down")), i18n("Move Down"));
         connect(action, &QAction::triggered, [=]() {moveToNext();});
-        action->setShortcut(Qt::CTRL + Qt::Key_Down);
+        action->setShortcut(Qt::CTRL | Qt::Key_Down);
         menu->insertAction(firstAction, action);
         menu->insertSeparator(firstAction);
     }
 
     action = new QAction(QIcon::fromTheme(QLatin1String("edit-delete")), i18n("Delete"));
     connect(action, &QAction::triggered, [=]() {startRemoving();});
-    action->setShortcut(Qt::ShiftModifier + Qt::Key_Delete);
+    action->setShortcut(Qt::ShiftModifier | Qt::Key_Delete);
     menu->insertAction(firstAction, action);
     menu->insertSeparator(firstAction);
 
@@ -714,8 +715,8 @@ void WorksheetEntry::startRemoving(bool warn)
 
     if (warn && Settings::warnAboutEntryDelete())
     {
-        int rc = KMessageBox::warningYesNo(nullptr, i18n("This step cannot be undone. Do you really want to delete this entry?"), i18n("Delete Entry"));
-        if (rc == KMessageBox::No)
+        int rc = KMessageBox::warningTwoActions(nullptr, i18n("This step cannot be undone. Do you really want to delete this entry?"), i18n("Delete Entry"), KStandardGuiItem::remove(), KStandardGuiItem::cancel());
+        if (rc == KMessageBox::SecondaryAction)
             return;
     }
 
